import json
import jieba
import jieba.posseg as pseg

# 加载实体属性数据
with open('attr.json', 'r', encoding='utf-8') as f:
    attr_data = json.load(f)

# 加载知识图谱数据
with open('links_and_nodes.json', 'r', encoding='utf-8') as f:
    graph_data = json.load(f)

def query_entity_property(entity, property_name):
    if entity in attr_data and property_name in attr_data[entity]:
        return attr_data[entity][property_name]
    else:
        return None

def query_relation(source, target):
    for link in graph_data['links']:
        if link['source'] == source and link['target'] == target:
            return link['relation']
    return None

def extract_entities_and_relation(question):
    words = list(pseg.cut(question))
    entities = []
    relation = None

    for word, flag in words:
        if flag.startswith('n'):
            entities.append(word)
        elif flag == 'c':
            relation = word

    return entities, relation

def answer_question(question):
    entities, relation = extract_entities_and_relation(question)
    print(entities, relation)
    if len(entities) < 2:
        return "请提供足够的实体信息来回答问题。"

    if relation:
        source, target = entities[:2]
        relation = query_relation(source, target)
        if relation:
            return f"{source}和{target}之间的关系是{relation}"
        else:
            return f"{source}和{target}之间没有关系"
    else:
        entity = entities[0]
        property_name = entities[1]
        property_value = query_entity_property(entity, property_name)
        if property_value:
            return f"{entity}的{property_name}是{property_value}"
        else:
            return f"{entity}没有{property_name}这个属性"

if __name__ == "__main__":
    while True:
        question = input("请输入您的问题：")
        if question.lower() == 'exit':
            print("感谢使用，再见！")
            break
        else:
            answer = answer_question(question)
            print(answer)
